package vsp.gaussian;

import java.util.ArrayList;

public class Histogram {

	private ArrayList<Double> values;
	
	@SuppressWarnings("unused")
	private Params params;
	private long from;
	private long to;
	@SuppressWarnings("unused")
	private int steps;
	private double step;
	
	private int[] histogram;
	
	/**
	 * Create histogram
	 * 
	 * @param from histogram begin
	 * @param to histogram end
	 * @param steps number of steps
	 */
	public Histogram(Params params, int steps) {
		this.params = params;
		this.steps = steps;
		
		from = Math.round(params.getMedian() - params.getDeviation() - 1);
		to = Math.round(params.getMedian() + params.getDeviation() + 1);
		
		values = new ArrayList<Double>();
		histogram = fillZeros(new int[steps + 3]);
		step = (to - from) / (steps + 0.0);
	}
	
	/**
	 * Add new value to histogram
	 * @param num new number to histogram
	 */
	public void addValue(double num) {
		values.add(num);
		
		for (int i = 0; i < histogram.length; i++) {
			if (num < (from + (i * step))) {
				histogram[i]++;
				break;
			}
		}
	}
	
	/**
	 * Fill empty arrays with zero
	 * @param array new array
	 * @return array with zeros on each index
	 */
	private int[] fillZeros(int[] array) {
		for (int i = 0; i < array.length; i++) {
			array[i] = 0;
		}
		return array;
	}
	
	/**
	 * Basic string output for development
	 */
	public String toString() {
		String str = "";
		int sum = 0;
		
		for (int i : histogram) {
			str += i + " | ";
			sum += i;
		}
		
		return str + "\n" + sum;
	}
	
	public void printHistogram() {
		
	}
}
