package vsp.config;

/**
 * 
 * Implamentation of configuration for exponentian
 * 
 * @author Jan Tichava
 *
 */
public class ConfigExp implements Config {

	/**
	 * Lambda for electronics input - default value
	 */
	private double lambdaElectronics = 1;
	/**
	 * Lambda for paper input - default value
	 */
	private double lambdaPaper = 0.8;
	
	/**
	 * Probability p1 - default value
	 */
	private double p1 = 0.6;
	/**
	 * Probability p2 - default value
	 */
	private double p2 = 0.9;
	/**
	 * Probability p3 - default value
	 */
	private double p3 = 0.95;
	
	/**
	 * Mean service time for server 1 - default value
	 */
	private double ts1 = 0.5;
	/**
	 * Mean service time for server 2 - default value
	 */
	private double ts2 = 0.7;
	/**
	 * Mean service time for server 3 - default value
	 */
	private double ts3 = 0.3;
	/**
	 * Mean service time for server 4 - default value
	 */
	private double ts4 = 0.4;
	
	/**
	 * Number of steps  - default value
	 */
	private int steps = 10000;
	/**
	 * Statistics scanning time  - default value
	 */
	private long scanTime = 10;
	
	/**
	 * Creates new configuration
	 * 
	 * @param lambdaElectronics
	 * @param lambdaPaper
	 * @param p1
	 * @param p2
	 * @param p3
	 * @param ts1
	 * @param ts2
	 * @param ts3
	 * @param ts4
	 * @param steps
	 * @param scanTime
	 */
	public ConfigExp(double lambdaElectronics, double lambdaPaper, double p1, double p2, double p3, double ts1, double ts2, double ts3, double ts4, int steps, long scanTime) {
		this.lambdaElectronics = lambdaElectronics;
		this.lambdaPaper = lambdaPaper;
		this.p1 = p1;
		this.p2 = p2;
		this.p3 = p3;
		this.ts1 = ts1;
		this.ts2 = ts2;
		this.ts3 = ts3;
		this.ts4 = ts4;
		this.steps = steps;
		this.scanTime = scanTime;
	}
	
	/**
	 * Creates configuration with default values
	 */
	public ConfigExp() {
		
	}
	
	/**
	 * Creates configuration with default values, except steps count
	 * @param steps number of steps
	 */
	public ConfigExp(int steps) {
		this.steps = steps;
	}

	/**
	 * @return the lambdaElectronics
	 */
	public double getLambdaElectronics() {
		return lambdaElectronics;
	}

	/**
	 * @return the lambdaPaper
	 */
	public double getLambdaPaper() {
		return lambdaPaper;
	}

	/**
	 * @return the p1
	 */
	public double getP1() {
		return p1;
	}

	/**
	 * @return the p2
	 */
	public double getP2() {
		return p2;
	}

	/**
	 * @return the p3
	 */
	public double getP3() {
		return p3;
	}

	/**
	 * @return the ts1
	 */
	public double getTs1() {
		return ts1;
	}

	/**
	 * @return the ts2
	 */
	public double getTs2() {
		return ts2;
	}

	/**
	 * @return the ts3
	 */
	public double getTs3() {
		return ts3;
	}

	/**
	 * @return the ts4
	 */
	public double getTs4() {
		return ts4;
	}

	/**
	 * @return the steps
	 */
	public int getSteps() {
		return steps;
	}

	/**
	 * @return the scanTime
	 */
	public long getScanTime() {
		return scanTime;
	}

	/**
	 * @param lambdaElectronics the lambdaElectronics to set
	 */
	public void setLambdaElectronics(double lambdaElectronics) {
		this.lambdaElectronics = lambdaElectronics;
	}

	/**
	 * @param lambdaPaper the lambdaPaper to set
	 */
	public void setLambdaPaper(double lambdaPaper) {
		this.lambdaPaper = lambdaPaper;
	}

	/**
	 * @param p1 the p1 to set
	 */
	public void setP1(double p1) {
		this.p1 = p1;
	}

	/**
	 * @param p2 the p2 to set
	 */
	public void setP2(double p2) {
		this.p2 = p2;
	}

	/**
	 * @param p3 the p3 to set
	 */
	public void setP3(double p3) {
		this.p3 = p3;
	}

	/**
	 * @param ts1 the ts1 to set
	 */
	public void setTs1(double ts1) {
		this.ts1 = ts1;
	}

	/**
	 * @param ts2 the ts2 to set
	 */
	public void setTs2(double ts2) {
		this.ts2 = ts2;
	}

	/**
	 * @param ts3 the ts3 to set
	 */
	public void setTs3(double ts3) {
		this.ts3 = ts3;
	}

	/**
	 * @param ts4 the ts4 to set
	 */
	public void setTs4(double ts4) {
		this.ts4 = ts4;
	}

	/**
	 * @param steps the steps to set
	 */
	public void setSteps(int steps) {
		this.steps = steps;
	}

	/**
	 * @param scanTime the scanTime to set
	 */
	public void setScanTime(long scanTime) {
		this.scanTime = scanTime;
	}
}
